==> xwrf-0.0.2.tar.gz: xwrf-0.0.2/README.md <==
# xWRF

![Project logo displaying the name xWRF, with the X made of triangles pointing to a center point and tick marks bordering each letter](https://github.com/xarray-contrib/xwrf/raw/main/docs/source/_static/xwrf_logo_bg_light.svg#gh-light-mode-only)![](docs/source/_static/xwrf_logo_bg_dark.svg#gh-dark-mode-only)

| CI          | [![GitHub Workflow Status][github-ci-badge]][github-ci-link] [![Code Coverage Status][codecov-badge]][codecov-link] [![pre-commit.ci status][pre-commit.ci-badge]][pre-commit.ci-link] |
| :---------- | :------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------: |
| **Docs**    |                                                                     [![Documentation Status][rtd-badge]][rtd-link]                                                                     |
| **Package** |                                                          [![Conda][conda-badge]][conda-link] [![PyPI][pypi-badge]][pypi-link]                                                          |
| **License** |                                                                         [![License][license-badge]][repo-link]                                                                         |

A lightweight interface for working with the [Weather Research and Forecasting (WRF)](https://www2.mmm.ucar.edu/wrf/users/) model output in Xarray. The primary objective of `xWRF` is to replicate crucial functionality from the [wrf-python](https://github.com/NCAR/wrf-python) package in a way that is **more convenient** for users and provides **seamless integration** with the rest of the Pangeo software stack.

See [documentation](https://xwrf.readthedocs.io/) for more information.

[github-ci-badge]: https://img.shields.io/github/workflow/status/xarray-contrib/xwrf/CI?label=CI&logo=github
[github-ci-link]: https://github.com/xarray-contrib/xwrf/actions?query=workflow%3ACI
[codecov-badge]: https://img.shields.io/codecov/c/github/xarray-contrib/xwrf.svg?logo=codecov
[codecov-link]: https://codecov.io/gh/xarray-contrib/xwrf
[rtd-badge]: https://img.shields.io/readthedocs/xwrf/latest.svg
[rtd-link]: https://xwrf.readthedocs.io/en/latest/?badge=latest
[pypi-badge]: https://img.shields.io/pypi/v/xwrf?logo=pypi
[pypi-link]: https://pypi.org/project/xwrf
[conda-badge]: https://img.shields.io/conda/vn/conda-forge/xwrf?logo=anaconda
[conda-link]: https://anaconda.org/conda-forge/xwrf
[license-badge]: https://img.shields.io/github/license/xarray-contrib/xwrf
[repo-link]: https://github.com/xarray-contrib/xwrf
[pre-commit.ci-badge]: https://results.pre-commit.ci/badge/github/xarray-contrib/xwrf/main.svg
[pre-commit.ci-link]: https://results.pre-commit.ci/latest/github/xarray-contrib/xwrf/main

==> xwrf-0.0.5.tar.gz: xwrf-0.0.5/README.md <==
# xWRF

![Project logo displaying the name xWRF, with the X made of triangles pointing to a center point and tick marks bordering each letter](https://github.com/xarray-contrib/xwrf/raw/main/docs/source/_static/xwrf_logo_bg_light.svg#gh-light-mode-only)![](docs/source/_static/xwrf_logo_bg_dark.svg#gh-dark-mode-only)

| CI          | [![GitHub Workflow Status][github-ci-badge]][github-ci-link] [![Code Coverage Status][codecov-badge]][codecov-link] [![pre-commit.ci status][pre-commit.ci-badge]][pre-commit.ci-link] |
| :---------- | :------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------: |
| **Docs**    |                                                                     [![Documentation Status][rtd-badge]][rtd-link]                                                                     |
| **Package** |                                                          [![Conda][conda-badge]][conda-link] [![PyPI][pypi-badge]][pypi-link]                                                          |
| **License** |                                                                         [![License][license-badge]][repo-link]                                                                         |

A lightweight interface for working with the [Weather Research and Forecasting (WRF)](https://www2.mmm.ucar.edu/wrf/users/) model output in Xarray. The primary objective of `xWRF` is to replicate crucial functionality from the [wrf-python](https://github.com/NCAR/wrf-python) package in a way that is **more convenient** for users and provides **seamless integration** with the rest of the Pangeo software stack.

See [documentation](https://xwrf.readthedocs.io/) for more information.

[github-ci-badge]: https://img.shields.io/github/actions/workflow/status/xarray-contrib/xwrf/ci.yaml?branch=main
[github-ci-link]: https://github.com/xarray-contrib/xwrf/actions?query=workflow%3ACI
[codecov-badge]: https://img.shields.io/codecov/c/github/xarray-contrib/xwrf.svg?logo=codecov
[codecov-link]: https://codecov.io/gh/xarray-contrib/xwrf
[rtd-badge]: https://img.shields.io/readthedocs/xwrf/latest.svg
[rtd-link]: https://xwrf.readthedocs.io/en/latest/?badge=latest
[pypi-badge]: https://img.shields.io/pypi/v/xwrf?logo=pypi
[pypi-link]: https://pypi.org/project/xwrf
[conda-badge]: https://img.shields.io/conda/vn/conda-forge/xwrf?logo=anaconda
[conda-link]: https://anaconda.org/conda-forge/xwrf
[license-badge]: https://img.shields.io/github/license/xarray-contrib/xwrf
[repo-link]: https://github.com/xarray-contrib/xwrf
[pre-commit.ci-badge]: https://results.pre-commit.ci/badge/github/xarray-contrib/xwrf/main.svg
[pre-commit.ci-link]: https://results.pre-commit.ci/latest/github/xarray-contrib/xwrf/main
